@@ -1,4 +1,5 @@
 import os
+from typing import Optional
 
 
 class DefaultConfig:
@@ -12,6 +13,7 @@ class DefaultConfig:
         self.host = os.getenv("EXABEL_HOST", "data.api.exabel.com")
         self.port = int(os.getenv("EXABEL_PORT", "21443"))
         self.timeout = int(os.getenv("EXABEL_TIMEOUT", "30"))
+        self.root_certificates: Optional[str] = None
 
 
 class ClientConfig(DefaultConfig):
@@ -26,16 +28,18 @@ class ClientConfig(DefaultConfig):
         host: str = None,
         port: int = None,
         timeout: int = None,
+        root_certificates: str = None,
     ):
         """
         Initialize a new client configuration.
 
         Args:
-            api_key:        API key to use.
-            client_name:    Name of this client.
-            host:           Exabel API host.
-            port:           Exabel API port.
-            timeout:        Default timeout in seconds to use for API requests.
+            api_key:            API key to use.
+            client_name:        Name of this client.
+            host:               Exabel API host.
+            port:               Exabel API port.
+            timeout:            Default timeout in seconds to use for API requests.
+            root_certificates:  Additional allowed root certificates for verifying TLS connection.
         """
         super().__init__()
 
@@ -44,6 +48,7 @@ class ClientConfig(DefaultConfig):
         self.host = host or self.host
         self.port = port or self.port
         self.timeout = timeout or self.timeout
+        self.root_certificates = root_certificates or self.root_certificates
 
         if not self.api_key:
             raise ValueError("No API key given. Use of the Exabel SDK requires an API key.")
